@@ -1,19 +1,17 @@
 /*
- *  indent.c
- *  This file is part of Leafpad
- *
- *  Copyright (C) 2004 Tarot Osuji
- *
+ *  Leafpad - GTK+ based simple text editor
+ *  Copyright (C) 2004-2005 Tarot Osuji
+ *  
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
- *
+ *  
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *
+ *  
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -21,7 +19,7 @@
 
 #include <string.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
+//#include <gdk/gdkkeysyms.h>
 #include <undo.h>
 
 static gboolean auto_indent = FALSE;
@@ -63,11 +61,13 @@ void indent_real(GtkWidget *text_view)
 	
 	GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_view));
 	
+	g_signal_emit_by_name(G_OBJECT(buffer), "begin-user-action");
 	gtk_text_buffer_delete_selection(buffer, TRUE, TRUE);
 	gtk_text_buffer_get_iter_at_mark(buffer, &iter, gtk_text_buffer_get_insert(buffer));
 	ind = compute_indentation(buffer, gtk_text_iter_get_line(&iter));
 	str = g_strconcat("\n", ind, NULL);
 	gtk_text_buffer_insert(buffer, &iter, str, -1);
+	g_signal_emit_by_name(G_OBJECT(buffer), "end-user-action");
 	g_free(str);
 	g_free(ind);
 	
@@ -139,7 +139,9 @@ void indent_multi_line_indent(GtkTextBuffer *buffer)
 	for (i = start_line; i < end_line; i++) {
 		gtk_text_buffer_get_iter_at_line(buffer, &iter, i);
 		gtk_text_buffer_place_cursor(buffer, &iter);
+		g_signal_emit_by_name(G_OBJECT(buffer), "begin-user-action");
 		gtk_text_buffer_insert(buffer, &iter, "\t", 1);
+		g_signal_emit_by_name(G_OBJECT(buffer), "end-user-action");
 		undo_set_sequency(TRUE);
 	}
 	undo_set_sequency(FALSE);
@@ -179,7 +181,6 @@ void indent_multi_line_unindent(GtkTextBuffer *buffer)
 	end_line = gtk_text_iter_get_line(&end_iter);
 	gtk_text_buffer_get_iter_at_mark(buffer, &iter, gtk_text_buffer_get_insert(buffer));
 	pos = gtk_text_iter_equal(&iter, &start_iter);
-//	for (i = start_line; i < end_line; i++) {
 	i = start_line;
 	do {
 		ind = compute_indentation(buffer, i);
@@ -190,13 +191,14 @@ void indent_multi_line_unindent(GtkTextBuffer *buffer)
 			end_iter = start_iter;
 			gtk_text_iter_forward_chars(&end_iter, len);
 			gtk_text_buffer_move_mark_by_name(buffer, "insert", &end_iter);
+			g_signal_emit_by_name(G_OBJECT(buffer), "begin-user-action");
 			gtk_text_buffer_delete(buffer, &start_iter, &end_iter);
+			g_signal_emit_by_name(G_OBJECT(buffer), "end-user-action");
 			undo_set_sequency(TRUE);
 			g_free(ind);
 		}
 		i++;
 	} while (i < end_line);
-//	}
 	undo_set_sequency(FALSE);
 	
 	gtk_text_buffer_get_iter_at_line(buffer, &start_iter, start_line);
